@@ -5,6 +5,7 @@ from django.core.urlresolvers import reverse
 from django.conf import settings
 from django.forms import widgets
 from django.forms.util import flatatt
+from django.utils.datastructures import MultiValueDict, MergeDict
 from django.utils.html import escape, conditional_escape
 from django.utils.encoding import force_unicode
 from django.utils.safestring import mark_safe
@@ -72,7 +73,7 @@ class Select(widgets.Input):
         self.choices = iter(choices)
 
     def reverse(self, lookup_view):
-        opts = self.field.model._meta
+        opts = getattr(self, 'model', self.field.model)._meta
         return reverse(lookup_view, kwargs={
             'app_label': opts.app_label,
             'model_name': opts.object_name.lower(),
@@ -129,7 +130,9 @@ class Select(widgets.Input):
             value = ''
         final_attrs = self.build_attrs(attrs, name=name)
         output = [u'<select%s>' % flatatt(final_attrs)]
-        options = self.render_options(choices, [value])
+        if not isinstance(value, (list, tuple)):
+            value = [value]
+        options = self.render_options(choices, value)
         if options:
             output.append(options)
         output.append(u'</select>')
@@ -165,13 +168,24 @@ class Select(widgets.Input):
 
 class SelectMultiple(Select):
 
-    def __init__(self, js_options=None, *args, **kwargs):
-        options = {
-            'multiple': True,
-        }
+    allow_multiple_selected = True
+
+    def __init__(self, attrs=None, choices=(), js_options=None, *args, **kwargs):
+        options = {}
+        default_attrs = {}
+        ajax = kwargs.get('ajax', self.ajax)
+        if ajax:
+            options.update({'multiple': True,})
+        else:
+            default_attrs.update({
+                'multiple': 'multiple',
+            })
+        attrs = dict(default_attrs, **attrs) if attrs else default_attrs
         if js_options is not None:
             options.update(js_options)
-        super(SelectMultiple, self).__init__(js_options=options, *args, **kwargs)
+
+        super(SelectMultiple, self).__init__(attrs=attrs, choices=choices,
+                js_options=options, *args, **kwargs)
 
     def _format_value(self, value):
         if isinstance(value, list):
@@ -181,3 +195,8 @@ class SelectMultiple(Select):
     def _has_changed(self, initial, data):
         initial = self._format_value(initial)
         return super(SelectMultiple, self)._has_changed(initial, data)
+
+    def value_from_datadict(self, data, files, name):
+        if isinstance(data, (MultiValueDict, MergeDict)):
+            return data.getlist(name)
+        return data.get(name, None)
